cumulusci.core.config package
=============================

Submodules
----------

cumulusci.core.config.BaseConfig module
---------------------------------------

.. automodule:: cumulusci.core.config.BaseConfig
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.config.BaseGlobalConfig module
---------------------------------------------

.. automodule:: cumulusci.core.config.BaseGlobalConfig
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.config.BaseProjectConfig module
----------------------------------------------

.. automodule:: cumulusci.core.config.BaseProjectConfig
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.config.BaseTaskFlowConfig module
-----------------------------------------------

.. automodule:: cumulusci.core.config.BaseTaskFlowConfig
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.config.OrgConfig module
--------------------------------------

.. automodule:: cumulusci.core.config.OrgConfig
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.core.config.ScratchOrgConfig module
---------------------------------------------

.. automodule:: cumulusci.core.config.ScratchOrgConfig
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.core.config
    :members:
    :undoc-members:
    :show-inheritance:
